@@ -1,5 +1,6 @@
 #import "Myapp.h"
 #import "RLE.h"
+#import "RASF.h"
 #import <rle.h>
 #import <stdio.h>
 #import <stdlib.h>
@@ -28,7 +29,10 @@
     id                  ptr;
  
     [self activateSelf:NO];
-    ptr = [RLE new];
+    if (!strcmp(type,"rle"))
+	ptr = [[RLE alloc]init];
+    else
+	ptr = [[RASF alloc]init];
     [ptr open:(char *)fullPath];
     return YES;
 }
@@ -40,21 +44,27 @@
 
 - openfile:sender
 {
-    char                      temp[500];
+    char                      temp[1024];
+    char                      directory[1024];
+    char                     *extension;
     id                        ptr;
     int                       loop;
-    static const char  *const opentypes[] = {"rle",NULL};
+    static const char  *const opentypes[] = {"rle","rasf",NULL};
 
     openpanel = [OpenPanel new];
     [openpanel allowMultipleFiles:YES];
 
     if ([openpanel runModalForTypes:opentypes]) {
 	loop = 0;
+	strncpy(directory,[openpanel directory],1024);
 	while ([openpanel filenames][loop]) {
-	    strcpy(temp,[openpanel directory]);
-	    strcat(temp, "/");
-	    strcat(temp,[openpanel filenames][loop]);
-	    ptr = [RLE new];
+	    sprintf(temp,"%s/%s",directory,[openpanel filenames][loop]);
+	    extension = rindex(temp,'.');
+	    if (!strcmp(extension,".rle"))
+		ptr = [[RLE alloc]init];
+	    else
+		ptr = [[RASF alloc]init];
+
 	    [ptr open:temp];
 	    ++loop;
 	}
