@@ -21,7 +21,7 @@
     NXRect              temprect;	 // Temp place to store Window Rect
 }
 
-+ new;
+- init;
 - open:(char *)fileName;
 - drawSelf:(const NXRect *)rects :(int)rectCount;
 - free;
